==> dev.biuro-1.14.0.tar.gz: dev.biuro-1.14.0/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--position--step-2.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<?php

    # sitie po submito;
    $nameValue = $_SESSION['position--name-value'];
    $nameStatus = $_SESSION['position--name-status'];
    $nameMessage = __($_SESSION['position--name-message'], 'biuro-contacts');

    $phoneValue = $_SESSION['position--phone-value'];
    $phoneStatus = $_SESSION['position--phone-status'];
    $phoneMessage = __($_SESSION['position--phone-message'], 'biuro-contacts');

    $emailValue = $_SESSION['position--email-value'];
    $emailStatus = $_SESSION['position--email-status'];
    $emailMessage = __($_SESSION['position--email-message'], 'biuro-contacts');

    $cvValue = $_SESSION['position--cv-value'];
    $cvStatus = $_SESSION['position--cv-status'];
    $cvMessage = __($_SESSION['position--cv-message'], 'biuro-contacts');

/*
    $agreeValue = $_SESSION['position--agree-value'];
    $agreeStatus = $_SESSION['position--agree-status'];
    $agreeMessage = __($_SESSION['position--agree-message'], 'biuro-contacts');
*/
    $cvValue = $_SESSION['position--cv-value'];
    $cityValue = $_SESSION['position--city-value'];
    $cityIDValue = $_SESSION['position--city_id-value'];
    $messageValue = $_SESSION['position--message-value'];
    $confirmValue = $_SESSION['position--confirm-value'];

    if(is_numeric($_SESSION['employees--id']) && $_SESSION['position--s'] === 1) {
        $employeeData = Biuro_Contacts_Public::fetchRow($_SESSION['employees--id']);

        $nameValue = $employeeData['name'];
        $phoneValue = $employeeData['phone'];
        $emailValue = $employeeData['email'];
        $cityValue = $employeeData['city'];
        $cityIDValue = $employeeData['city_id'];
    }

?>
    <div class="c-form--row">
        <label class="c-form--label" for="form-name"><?php _e('Name, surname', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($nameStatus) { echo "c-form--input-wrap--$nameStatus"; } ?>">
            <input type="text" class="c-form--input" id="form-name" name="name" value="<?php echo $nameValue; ?>" <?php if ($nameStatus == 'error' || !$nameValue && $_SESSION['position--s'] === 2): ?> autofocus="autofocus" <?php endif; ?>>
        </div>
        <?php if ($nameMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $nameStatus; ?>">
                <?php echo $nameMessage; ?>
            </div>
        <?php endif; ?>
    </div>


    <div class="c-form--row">
        <label class="c-form--label" for="form-phone"><?php _e('Phone no.', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($phoneStatus) { echo "c-form--input-wrap--$phoneStatus"; } ?>">
            <input type="tel" class="c-form--input" id="form-phone" name="phone" value="<?php echo $phoneValue; ?>" <?php if ($nameStatus != 'error' && $phoneStatus == 'error'): ?> autofocus="autofocus" <?php endif; ?>>
        </div>
        <?php if ($phoneMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $phoneStatus; ?>">
                <?php echo $phoneMessage; ?>
            </div>
        <?php endif; ?>
    </div>


    <div class="c-form--row">
        <label class="c-form--label" for="form-email"><?php _e('Email address', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($emailStatus) { echo "c-form--input-wrap--$emailStatus"; } ?>">
                <input type="email" class="c-form--input" id="form-email" name="email" value="<?php echo $emailValue; ?>">
        </div>
        <?php if ($emailMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $emailStatus; ?>">
                <?php echo $emailMessage; ?>
            </div>
        <?php endif; ?>
    </div>

    <div class="c-form--row">
        <label class="c-form--label" for="form-city"><?php _e('City', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap c-form--autocomplete">
            <datalist id="form-cities">
<?php
            $cities = get_terms( array(
                'taxonomy' => 'city',
                'hide_empty' => false,
            ) );

            foreach ( $cities as $city ):
?>
                <option value="<?php echo preg_replace('/\D/', '', $city->slug); ?>"><?php echo $city->name; ?></option>
<?php
            endforeach;
?>
            </datalist>
            <input list="form-cities" type="text" class="c-form--input" id="form-city" name="city" value="<?php echo $cityValue; ?>">
            <input type="hidden" id="form-city-id" name="city_id" value="<?php echo $cityIDValue; ?>">
        </div>
    </div>

    <div id="agree"></div>

    <div class="c-form--row">
        <label class="c-form--label" for="form-message"><?php _e('Message', 'biuro-contacts'); ?></label>
        <div class="c-form--textarea-wrap">
            <textarea name="message" id="form-message" cols="30" rows="3" class="c-form--textarea" placeholder="<?php _e("For example: I'm looking for a job in manufacturing", 'biuro-contacts'); ?>"><?php echo $messageValue; ?></textarea>
        </div>
    </div>

    <div class="c-form--row">
        <div class="c-form--input-file-wrap">
            <input type="file" class="js-form--input-file c-form--input-file" id="form-cv" name="cv" accept="application/pdf, application/doc, application/docx, application/rtf, application/txt, application/odf, application/msword, image/jpg, image/jpeg, image/png">
            <button class="c-form--input-file-btn">
                <svg width="16px" height="21px" class="c-ico--attachment">
                    <use xlink:href="#ico--attachment"></use>
                </svg>
                <span class="js-form--input-file-text c-form--input-file-text"><?php _e('CV', 'biuro-contacts'); ?></span>
            </button>
        </div>
        <?php if ($cvMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $cvStatus; ?>">
                <?php echo $cvMessage; ?>
            </div>
        <?php endif; ?>
    </div>

    <div class="c-form--row">
        <div class="c-form--label-infobox">
            <?php _e('We process your personal data to offer you jobs. More information at <a href="https://biuro.eu/privacy-en.html" target="_blank" rel="noopener">Personal Data Protection Policy.</a>', 'biuro-contacts'); ?>
            <input type="hidden" name="agree" value="1">
        </div>
    </div>

    <div class="c-form--row">
        <div class="c-form--submit-wrap">
            <button type="submit" class="o-btn c-btn--main c-btn--fill" name="s" value="2"><?php _e('Apply', 'biuro-contacts'); ?></button>
        </div>
    </div>

    <div class="c-form--label-recaptcha">
        <?php _e('This site is protected by reCAPTCHA and the Google <a href="https://policies.google.com/privacy">Privacy Policy</a> and <a href="https://policies.google.com/terms">Terms of Service</a> apply.', 'biuro-contacts'); ?>
    </div>

==> dev.biuro-1.20.1.tar.gz: dev.biuro-1.20.1/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--position--step-2.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<?php

    # sitie po submito;
    $nameValue = $_SESSION['position--name-value'];
    $nameStatus = $_SESSION['position--name-status'];
    $nameMessage = __($_SESSION['position--name-message'], 'biuro-contacts');

    $phoneValue = $_SESSION['position--phone-value'];
    $phoneStatus = $_SESSION['position--phone-status'];
    $phoneMessage = __($_SESSION['position--phone-message'], 'biuro-contacts');

    $emailValue = $_SESSION['position--email-value'];
    $emailStatus = $_SESSION['position--email-status'];
    $emailMessage = __($_SESSION['position--email-message'], 'biuro-contacts');

    $cvValue = $_SESSION['position--cv-value'];
    $cvStatus = $_SESSION['position--cv-status'];
    $cvMessage = __($_SESSION['position--cv-message'], 'biuro-contacts');

/*
    $agreeValue = $_SESSION['position--agree-value'];
    $agreeStatus = $_SESSION['position--agree-status'];
    $agreeMessage = __($_SESSION['position--agree-message'], 'biuro-contacts');
*/
    $cvValue = $_SESSION['position--cv-value'];
    $cityValue = $_SESSION['position--city-value'];
    $cityIDValue = $_SESSION['position--city_id-value'];
    $messageValue = $_SESSION['position--message-value'];
    $confirmValue = $_SESSION['position--confirm-value'];

    if(is_numeric($_SESSION['employees--id']) && $_SESSION['position--s'] === 1) {
        $employeeData = Biuro_Contacts_Public::fetchRow($_SESSION['employees--id']);

        $nameValue = $employeeData['name'];
        $phoneValue = $employeeData['phone'];
        $emailValue = $employeeData['email'];
        $cityValue = $employeeData['city'];
        $cityIDValue = $employeeData['city_id'];
    }

?>
    <div class="c-form--row">
        <label class="c-form--label" for="form-name"><?php _e('Name, surname', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($nameStatus) { echo "c-form--input-wrap--$nameStatus"; } ?>">
            <input type="text" class="c-form--input" id="form-name" name="name" value="<?php echo $nameValue; ?>" <?php if ($nameStatus == 'error' || !$nameValue && $_SESSION['position--s'] === 2): ?> autofocus="autofocus" <?php endif; ?>>
        </div>
        <?php if ($nameMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $nameStatus; ?>">
                <?php echo $nameMessage; ?>
            </div>
        <?php endif; ?>
    </div>


    <div class="c-form--row">
        <label class="c-form--label" for="form-phone"><?php _e('Phone no.', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($phoneStatus) { echo "c-form--input-wrap--$phoneStatus"; } ?>">
            <input type="tel" class="c-form--input" id="form-phone" name="phone" value="<?php echo $phoneValue; ?>" <?php if ($nameStatus != 'error' && $phoneStatus == 'error'): ?> autofocus="autofocus" <?php endif; ?>>
        </div>
        <?php if ($phoneMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $phoneStatus; ?>">
                <?php echo $phoneMessage; ?>
            </div>
        <?php endif; ?>
    </div>


    <div class="c-form--row">
        <label class="c-form--label" for="form-email"><?php _e('Email address', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap <?php if ($emailStatus) { echo "c-form--input-wrap--$emailStatus"; } ?>">
                <input type="email" class="c-form--input" id="form-email" name="email" value="<?php echo $emailValue; ?>">
        </div>
        <?php if ($emailMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $emailStatus; ?>">
                <?php echo $emailMessage; ?>
            </div>
        <?php endif; ?>
    </div>

    <div class="c-form--row">
        <label class="c-form--label" for="form-city"><?php _e('City', 'biuro-contacts'); ?></label>
        <div class="c-form--input-wrap c-form--autocomplete">
            <datalist id="form-cities">
<?php
            $cities = get_terms( array(
                'taxonomy' => 'city',
                'hide_empty' => false,
            ) );

            foreach ( $cities as $city ):
?>
                <option value="<?php echo preg_replace('/\D/', '', $city->slug); ?>"><?php echo $city->name; ?></option>
<?php
            endforeach;
?>
            </datalist>
            <input list="form-cities" type="text" class="c-form--input" id="form-city" name="city" value="<?php echo $cityValue; ?>">
            <input type="hidden" id="form-city-id" name="city_id" value="<?php echo $cityIDValue; ?>">
        </div>
    </div>

    <div id="agree"></div>

    <div class="c-form--row">
        <label class="c-form--label" for="form-message"><?php _e('Message', 'biuro-contacts'); ?></label>
        <div class="c-form--textarea-wrap">
            <textarea name="message" id="form-message" cols="30" rows="3" class="c-form--textarea" placeholder="<?php _e("For example: I'm looking for a job in manufacturing", 'biuro-contacts'); ?>"><?php echo $messageValue; ?></textarea>
        </div>
    </div>

    <div class="c-form--row">
        <div class="c-form--input-file-wrap">
            <input type="file" class="js-form--input-file c-form--input-file" id="form-cv" name="cv" accept="application/pdf, application/doc, application/docx, application/rtf, application/txt, application/odf, application/msword, image/jpg, image/jpeg, image/png">
            <button class="c-form--input-file-btn">
                <svg width="16px" height="21px" class="c-ico--attachment">
                    <use href="#ico--attachment"></use>
                </svg>
                <span class="js-form--input-file-text c-form--input-file-text"><?php _e('CV', 'biuro-contacts'); ?></span>
            </button>
        </div>
        <?php if ($cvMessage): ?>
            <div class="c-form--validation c-form--validation-<?php echo $cvStatus; ?>">
                <?php echo $cvMessage; ?>
            </div>
        <?php endif; ?>
    </div>

    <div class="c-form--row">
        <div class="c-form--label-infobox">
            <?php _e('We process your personal data to offer you jobs. More information at <a href="https://biuro.eu/privacy-en.html" target="_blank" rel="noopener">Personal Data Protection Policy.</a>', 'biuro-contacts'); ?>
            <input type="hidden" name="agree" value="1">
        </div>
    </div>

    <div class="c-form--row">
        <div class="c-form--submit-wrap">
            <button type="submit" class="o-btn c-btn--main c-btn--fill" name="s" value="2"><?php _e('Apply', 'biuro-contacts'); ?></button>
        </div>
    </div>

    <div class="c-form--label-recaptcha">
        <?php _e('This site is protected by reCAPTCHA and the Google <a href="https://policies.google.com/privacy">Privacy Policy</a> and <a href="https://policies.google.com/terms">Terms of Service</a> apply.', 'biuro-contacts'); ?>
    </div>
